@@ -3,7 +3,6 @@ from norminette.lexer.dictionary import operators
 from norminette.norm_error import NormError
 from norminette.scope import GlobalScope, ControlStructure
 from norminette.tools.colors import colors
-
 types = [
     "CHAR",
     "DOUBLE",
@@ -114,6 +113,20 @@ misc_specifiers = [
     "UNSIGNED",
 ]
 
+assigns = [
+    "RIGHT_ASSIGN",
+    "LEFT_ASSIGN",
+    "ADD_ASSIGN",
+    "SUB_ASSIGN",
+    "MUL_ASSIGN",
+    "DIV_ASSIGN",
+    "MOD_ASSIGN",
+    "AND_ASSIGN",
+    "XOR_ASSIGN",
+    "OR_ASSIGN",
+    "ASSIGN",
+]
+
 size_specifiers = ["LONG", "SHORT"]
 
 sign_specifiers = ["SIGNED", "UNSIGNED"]
@@ -442,19 +455,16 @@ In \"{self.scope.name}\" from \
         while pos > 0:
             if self.check_token(pos, ["RBRACKET", "RPARENTHESIS"]) is True:
                 pos = self.skip_nest_reverse(pos) - 1
-                if self.check_token(pos, "RPARENTHESIS") is True and self.parenthesis_contain(pos + 1)[0] == "cast":
+                if self.check_token(pos + 1, "LPARENTHESIS") is True and self.parenthesis_contain(pos + 1)[0] == "cast":
                     return False
                 skip = 1
-            if self.check_token(pos, ["IDENTIFIER", "CONSTANT", "SIZEOF"]) is True:
+            if self.check_token(pos, ["IDENTIFIER", "CONSTANT", "SIZEOF", "CHAR_CONST"]) is True:
                 if self.check_token(pos, "IDENTIFIER") is True and self.check_token(pos + 1, "TAB") is True:
                     return False
                 return True
-            if self.check_token(pos, ["COMMA", "LPARENTHESIS"] + operators) is True and skip == 1:
+            if self.check_token(pos, ["COMMA", "LPARENTHESIS"] + operators) is True and skip == 1 and self.parenthesis_contain(pos + 1)[0] != "cast":
                 return True
-            if self.check_token(
-                pos,
-                ["LBRACKET", "LPARENTHESIS", "MULT", "BWISE_AND", "COMMA"] + operators + types,
-            ):
+            if self.check_token(pos, ["LBRACKET", "LPARENTHESIS", "MULT", "BWISE_AND", "COMMA"] + operators + types):
                 return False
             pos -= 1
         return False
@@ -465,6 +475,8 @@ In \"{self.scope.name}\" from \
         Function, pointer, cast, or other
         Uses basic string as return value and skips to the end of the parenthesis nest
         """
+        if self.check_token(i, "LPARENTHESIS") is False:
+            return None, i
         start = i
         ws = ["SPACE", "TAB", "NEWLINE"]
         i += 1
@@ -472,6 +484,7 @@ In \"{self.scope.name}\" from \
         nested_id = False
         identifier = None
         pointer = None
+        i = self.skip_ws(i)
         while deep > 0:
             if self.check_token(i, "RPARENTHESIS"):
                 deep -= 1
